#ifndef JSVRoboBilly_h
#define JSVRoboBilly_h

#include <Arduino.h>
#include "JSVMotor.h"
#include "NewPing.h"
#include <Servo.h>

//brief Class for JSV Robot Billy
/*
Be careful when using servo.h library, this renders pins 9 and 10 unusable for PWM signals ( analogWrites will become digitalWrites)
Be careful when using the speaker, the timer used in the arduino tone functions uses the same timer as PWM on pins 3 and 11
In this case, pin 3 is attached to the servo, so will be using the 16 bit timer, but pin 11 is the rightmotor PWM pin, there might be problems here
*/


class JSVRoboBilly
{
  private:
      //initializing pincofiguration
      //Motors
	  const uint8_t MotorLeftPin1 = 6;			//This has to be the PWM pin
      const uint8_t MotorLeftPin2 = 10;
      const uint8_t MotorRightPin1 = 11;		//This has to be the PWM pin
      const uint8_t MotorRightPin2 = 9;
	  const uint8_t MinMotorSpeed = 60;
	  const uint8_t MaxMotorSpeed = 150;
      JSVMotor LeftMotor;
      JSVMotor RightMotor;
      //Sonar
	  const uint8_t TrigPin = 5;
      const uint8_t EchoPin = 4;
      const int MaxDistanceCm = 300;
      const uint8_t PingQuality = 5; //The number of pings the sensor does before returning result.
      NewPing Sonar;
      //LEDs
	  const uint8_t LeftLEDPin = 7;
      const uint8_t RightLEDPin = 2;
      //Speaker
	  const uint8_t SpeakerPin = 8;
      //Bluetooth
	  const uint8_t BluetoothTxPin = 0;
      const uint8_t BluetoothRxPin = 1;
      const long BluetoothBaudRate = 115200; //using this baudrate for arduino uno because it is the same for the bootloader
      //Servos	  
	  const uint8_t LeftArmServoPin = 3;
      //const int RightArmServoPin = x // to be defined!!
      Servo LeftArm;
      Servo RightArm;
	public:
		JSVRoboBilly();
		void control_motor(int index, bool MotorDirection, uint8_t Percentage);
		void SetupLeftMotor(bool ReverseMotor, int Percentage);
		void SetupRightMotor(bool ReverseMotor, int Percentage);
		unsigned int getDistance();
		void LeftLEDSet(bool set);
		void RightLEDSet(bool set);
		void LeftLEDToggle();
		void RightLEDToggle();
	    void SpeakerPlayNote(int frequency);
	   	void SpeakerPlayNoteTime(int frequency, int time_ms);
	    void SpeakerStop();
	    void BluetoothOpenConnection();
	    bool BluetoothHasData();
		char BluetoothGetData();
		void BluetoothSendData(String data);
    	void InitServos();
		void SetLeftArmAngle(int angle);
		void SetRightArmAngle(int angle);
		int ReadLeftArmAngle();
		int ReadRightArmAngle();
	    
	private:
	    void LeftLEDOn();
	  	void LeftLEDOff();
	    void RightLEDOn();
	    void RightLEDOff();
	  	void SetServoAngle(Servo servomotor, int angle);
	  	int ReadServoAngle(Servo servomotor);
};

#endif
